Use base32 without padding in Python

[![Build Status](https://travis-ci.org/beardog108/python-unpaddedbase32.svg?branch=master)](https://travis-ci.org/beardog108/python-unpaddedbase32)

Allowed by [RFC 4648](https://tools.ietf.org/html/rfc4648#section-3.2)

Install: pip install unpaddedbase32

Python 3.6+
